@@ -1,4 +1,4 @@
-VERSION = (0, 1, 5, "final")
+VERSION = (0, 1, 6, "final")
 
 def get_version():
     if VERSION[3] != "final":
@@ -18,7 +18,8 @@ try:
     NOTIFICATION_USE_SITE = getattr(settings, 'NOTIFICATION_USE_SITE', False)
     NOTIFICATION_QUEUE_ALL = getattr(settings, "NOTIFICATION_QUEUE_ALL", False)
     NOTIFICATION_LANGUAGE_MODULE = getattr(settings, 
-                                           'NOTIFICATION_LANGUAGE_MODULE', False)
+                                           'NOTIFICATION_LANGUAGE_MODULE', 
+                                           False)
     NOTIFICATION_FEEDS = getattr(settings, "NOTIFICATION_FEEDS", False)
     NOTIFICATION_LOCK_WAIT_TIMEOUT = getattr(settings, 
                                              "NOTIFICATION_LOCK_WAIT_TIMEOUT", 
